# topology Schema

```
https://www.iopsys.eu/usp.raw.json
```

| Custom Properties | Additional Properties |
| ----------------- | --------------------- |
| Forbidden         | Forbidden             |

# topology

| List of Methods         |
| ----------------------- |
| [changelog](#changelog) | Method | topology (this schema) |
| [dump](#dump)           | Method | topology (this schema) |
| [nodes](#nodes)         | Method | topology (this schema) |
| [refresh](#refresh)     | Method | topology (this schema) |
| [status](#status)       | Method | topology (this schema) |

## changelog

### This object represents log entries for changes in the 1905 Network Topology.

`changelog`

- type: `Method`

### changelog Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `output` | object | **Required** |

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property        | Type    | Required |
| --------------- | ------- | -------- |
| `changelog`     | array   | Optional |
| `num_changelog` | integer | Optional |

#### changelog

`changelog`

- is optional
- type: `object[]`

##### changelog Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property             | Type    | Required |
| -------------------- | ------- | -------- |
| `event_type`         | string  | Optional |
| `is1905_neighbor`    | boolean | Optional |
| `neighbor`           | string  | Optional |
| `reporter`           | string  | Optional |
| `reporter_interface` | string  | Optional |
| `timestamp`          | integer | Optional |

#### event_type

`event_type`

- is optional
- type: reference

##### event_type Type

`string`

All instances must conform to this regular expression (test examples [here](https://regexr.com/?expression=add%7Cdel)):

```regex
add|del
```

#### is1905_neighbor

`is1905_neighbor`

- is optional
- type: `boolean`

##### is1905_neighbor Type

`boolean`

#### neighbor

mac address in string format

`neighbor`

- is optional
- type: reference

##### neighbor Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### reporter

mac address in string format

`reporter`

- is optional
- type: reference

##### reporter Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### reporter_interface

mac address in string format

`reporter_interface`

- is optional
- type: reference

##### reporter_interface Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### timestamp

Time the node was changed

`timestamp`

- is optional
- type: reference

##### timestamp Type

`integer`

- minimum value: `0`
- maximum value: `65535`

#### num_changelog

`num_changelog`

- is optional
- type: `integer`

##### num_changelog Type

`integer`

- minimum value: `1`
- maximum value: `255`

### Output Example

```json
{
  "num_changelog": 236,
  "changelog": [
    {
      "reporter": "d5:Ff:68:5c:fb:9a",
      "reporter_interface": "CC:Ec:2f:f3:76:DE",
      "neighbor": "b5:4F:8b:f2:6d:f2",
      "is1905_neighbor": false,
      "event_type": "add",
      "timestamp": 16618
    }
  ]
}
```

## dump

### Topology info of AL nodes and there parameters

`dump`

- type: `Method`

### dump Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `output` | object | Optional |

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `nodes`  | array  | Optional |
| `self`   | object | Optional |

#### nodes

`nodes`

- is optional
- type: `object[]`

##### nodes Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property                | Type    | Required |
| ----------------------- | ------- | -------- |
| `1905_nbr_localintf`    | string  | Optional |
| `bridge_tuple`          | array   | Optional |
| `bridging_tuple_num`    | integer | Optional |
| `control_url`           | string  | Optional |
| `friendly_name`         | string  | Optional |
| `ieee1905_macaddr`      | string  | Optional |
| `interfaces`            | array   | Optional |
| `ipv4_itfr_num`         | integer | Optional |
| `ipv4_params`           | array   | Optional |
| `ipv6_itfr_num`         | integer | Optional |
| `l2_neighbor`           | array   | Optional |
| `l2_neighbor_num`       | integer | Optional |
| `local_interface_nbr`   | integer | Optional |
| `manufacturer_model`    | string  | Optional |
| `manufacturer_name`     | string  | Optional |
| `neighbors`             | array   | Optional |
| `non1905_nbr_localintf` | string  | Optional |
| `non1905_neighbors`     | array   | Optional |
| `num_neighbors`         | integer | Optional |
| `num_non1905_neighbors` | integer | Optional |
| `registrar_freq_band`   | string  | Optional |
| `version`               | string  | Optional |

#### 1905_nbr_localintf

mac address in string format

`1905_nbr_localintf`

- is optional
- type: reference

##### 1905_nbr_localintf Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### bridge_tuple

`bridge_tuple`

- is optional
- type: `object[]`

##### bridge_tuple Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property | Type  | Required |
| -------- | ----- | -------- |
| `br_mac` | array | Optional |

#### br_mac

`br_mac`

- is optional
- type: reference

##### br_mac Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### bridging_tuple_num

`bridging_tuple_num`

- is optional
- type: `integer`

##### bridging_tuple_num Type

`integer`

- minimum value: `0`

#### control_url

`control_url`

- is optional
- type: `string`

##### control_url Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=%5Ehttp%3A%5C%2F(%5B0-255%5D%5C.)%7B3%7D%5B0-255%5D>)):

```regex
^http:\/([0-255]\.){3}[0-255]
```

#### friendly_name

`friendly_name`

- is optional
- type: `string`

##### friendly_name Type

`string`

#### ieee1905_macaddr

mac address in string format

`ieee1905_macaddr`

- is optional
- type: reference

##### ieee1905_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### interfaces

`interfaces`

- is optional
- type: `object[]`

##### interfaces Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property             | Type    | Required |
| -------------------- | ------- | -------- |
| `ap_channel_band`    | integer | Optional |
| `freq_index1`        | integer | Optional |
| `freq_index2`        | integer | Optional |
| `interface_id`       | string  | Optional |
| `media_type`         | string  | Optional |
| `network_membership` | string  | Optional |
| `role`               | string  | Optional |

#### ap_channel_band

`ap_channel_band`

- is optional
- type: `integer`

##### ap_channel_band Type

`integer`

- minimum value: `0`

#### freq_index1

`freq_index1`

- is optional
- type: `integer`

##### freq_index1 Type

`integer`

- minimum value: `0`

#### freq_index2

`freq_index2`

- is optional
- type: `integer`

##### freq_index2 Type

`integer`

- minimum value: `0`

#### interface_id

mac address in string format

`interface_id`

- is optional
- type: reference

##### interface_id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### media_type

Linux network interface type

`media_type`

- is optional
- type: reference

##### media_type Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=%5EIEEE%20802%5C.(3u%7C3ab%7C11b%7C11g%7C11a%7C11n%202.4%7C11n%205.0%7C11ac%7C11ad%7C11af)>)):

```regex
^IEEE 802\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)
```

#### network_membership

mac address in string format

`network_membership`

- is optional
- type: reference

##### network_membership Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### role

`role`

- is optional
- type: `string`

##### role Type

`string`

#### ipv4_itfr_num

`ipv4_itfr_num`

- is optional
- type: `integer`

##### ipv4_itfr_num Type

`integer`

- minimum value: `0`

#### ipv4_params

`ipv4_params`

- is optional
- type: `object[]`

##### ipv4_params Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property         | Type   | Required |
| ---------------- | ------ | -------- |
| `dhcp_addr`      | string | Optional |
| `ipv4_addr_type` | string | Optional |
| `ipv4_address`   | string | Optional |
| `mac_address`    | string | Optional |

#### dhcp_addr

IPv4 Address

`dhcp_addr`

- is optional
- type: reference

##### dhcp_addr Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(%5B0-255%5D%5C.)%7B3%7D%5B0-255%5D>)):

```regex
([0-255]\.){3}[0-255]
```

#### ipv4_addr_type

`ipv4_addr_type`

- is optional
- type: `string`

##### ipv4_addr_type Type

`string`

#### ipv4_address

IPv4 Address

`ipv4_address`

- is optional
- type: reference

##### ipv4_address Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(%5B0-255%5D%5C.)%7B3%7D%5B0-255%5D>)):

```regex
([0-255]\.){3}[0-255]
```

#### mac_address

mac address in string format

`mac_address`

- is optional
- type: reference

##### mac_address Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### ipv6_itfr_num

`ipv6_itfr_num`

- is optional
- type: `integer`

##### ipv6_itfr_num Type

`integer`

- minimum value: `0`

#### l2_neighbor

`l2_neighbor`

- is optional
- type: `object[]`

##### l2_neighbor Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property        | Type   | Required |
| --------------- | ------ | -------- |
| `local_intf_id` | string | Optional |
| `local_nbr_id`  | string | Optional |

#### local_intf_id

mac address in string format

`local_intf_id`

- is optional
- type: reference

##### local_intf_id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### local_nbr_id

mac address in string format

`local_nbr_id`

- is optional
- type: reference

##### local_nbr_id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### l2_neighbor_num

`l2_neighbor_num`

- is optional
- type: `integer`

##### l2_neighbor_num Type

`integer`

- minimum value: `0`

#### local_interface_nbr

`local_interface_nbr`

- is optional
- type: `integer`

##### local_interface_nbr Type

`integer`

- minimum value: `0`

#### manufacturer_model

`manufacturer_model`

- is optional
- type: `string`

##### manufacturer_model Type

`string`

#### manufacturer_name

`manufacturer_name`

- is optional
- type: `string`

##### manufacturer_name Type

`string`

#### neighbors

`neighbors`

- is optional
- type: `object[]`

##### neighbors Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property       | Type   | Required |
| -------------- | ------ | -------- |
| `link_metrics` | array  | Optional |
| `nbr_mac_id`   | string | Optional |

#### link_metrics

`link_metrics`

- is optional
- type: `object[]`

##### link_metrics Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property              | Type    | Required |
| --------------------- | ------- | -------- |
| `ieee_bridge`         | boolean | Optional |
| `link_availability`   | integer | Optional |
| `mac_thrput_capacity` | integer | Optional |
| `nbr_intf_macid`      | string  | Optional |
| `phy_rate`            | integer | Optional |
| `rssi`                | integer | Optional |
| `rx_packet_error`     | integer | Optional |
| `rx_packet_ok`        | integer | Optional |
| `tx_packet_error`     | integer | Optional |
| `tx_packet_ok`        | integer | Optional |

#### ieee_bridge

`ieee_bridge`

- is optional
- type: `boolean`

##### ieee_bridge Type

`boolean`

#### link_availability

`link_availability`

- is optional
- type: `integer`

##### link_availability Type

`integer`

- minimum value: `0`
- maximum value: `100`

#### mac_thrput_capacity

`mac_thrput_capacity`

- is optional
- type: `integer`

##### mac_thrput_capacity Type

`integer`

- minimum value: `0`

#### nbr_intf_macid

mac address in string format

`nbr_intf_macid`

- is optional
- type: reference

##### nbr_intf_macid Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### phy_rate

`phy_rate`

- is optional
- type: `integer`

##### phy_rate Type

`integer`

- minimum value: `0`

#### rssi

`rssi`

- is optional
- type: `integer`

##### rssi Type

`integer`

- minimum value: `0`

#### rx_packet_error

`rx_packet_error`

- is optional
- type: `integer`

##### rx_packet_error Type

`integer`

- minimum value: `0`

#### rx_packet_ok

`rx_packet_ok`

- is optional
- type: `integer`

##### rx_packet_ok Type

`integer`

- minimum value: `0`

#### tx_packet_error

`tx_packet_error`

- is optional
- type: `integer`

##### tx_packet_error Type

`integer`

- minimum value: `0`

#### tx_packet_ok

`tx_packet_ok`

- is optional
- type: `integer`

##### tx_packet_ok Type

`integer`

- minimum value: `0`

#### nbr_mac_id

mac address in string format

`nbr_mac_id`

- is optional
- type: reference

##### nbr_mac_id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### non1905_nbr_localintf

mac address in string format

`non1905_nbr_localintf`

- is optional
- type: reference

##### non1905_nbr_localintf Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### non1905_neighbors

`non1905_neighbors`

- is optional
- type: reference

##### non1905_neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### num_neighbors

`num_neighbors`

- is optional
- type: `integer`

##### num_neighbors Type

`integer`

- minimum value: `0`

#### num_non1905_neighbors

`num_non1905_neighbors`

- is optional
- type: `integer`

##### num_non1905_neighbors Type

`integer`

- minimum value: `0`

#### registrar_freq_band

mac address in string format

`registrar_freq_band`

- is optional
- type: reference

##### registrar_freq_band Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### version

`version`

- is optional
- type: `string`

##### version Type

`string`

All instances must conform to this regular expression (test examples
[here](<https://regexr.com/?expression=(1905%5C.1a%7C1905)>)):

```regex
(1905\.1a|1905)
```

#### self

`self`

- is optional
- type: `object`

##### self Type

`object` with following properties:

| Property                | Type    | Required |
| ----------------------- | ------- | -------- |
| `ieee1905_macaddr`      | string  | Optional |
| `neighbors`             | array   | Optional |
| `non1905_neighbors`     | array   | Optional |
| `num_neighbors`         | integer | Optional |
| `num_non1905_neighbors` | integer | Optional |

#### ieee1905_macaddr

mac address in string format

`ieee1905_macaddr`

- is optional
- type: reference

##### ieee1905_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### neighbors

`neighbors`

- is optional
- type: `object[]`

##### neighbors Type

Array type: `object[]`

All items must be of the type: `object` with following properties:

| Property     | Type   | Required |
| ------------ | ------ | -------- |
| `nbr_mac_id` | string | Optional |

#### nbr_mac_id

mac address in string format

`nbr_mac_id`

- is optional
- type: reference

##### nbr_mac_id Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### non1905_neighbors

`non1905_neighbors`

- is optional
- type: reference

##### non1905_neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

#### num_neighbors

`num_neighbors`

- is optional
- type: `integer`

##### num_neighbors Type

`integer`

- minimum value: `0`

#### num_non1905_neighbors

`num_non1905_neighbors`

- is optional
- type: `integer`

##### num_non1905_neighbors Type

`integer`

- minimum value: `0`

### Output Example

```json
{
  "self": {
    "ieee1905_macaddr": "E2:aE:30:3A:De:b9",
    "num_neighbors": 18387137,
    "neighbors": [
      { "nbr_mac_id": "71:F6:d3:38:BD:A0" },
      { "nbr_mac_id": "Ca:ef:e8:E9:d5:2e" },
      { "nbr_mac_id": "dF:b2:99:e2:6c:52" }
    ],
    "num_non1905_neighbors": 9369078,
    "non1905_neighbors": ["31:2b:15:8b:86:cc", "f0:4E:28:E0:Fb:eA", "4C:DF:6E:8D:5B:29"]
  },
  "nodes": [
    {
      "ieee1905_macaddr": "DA:dE:fb:fB:81:DA",
      "num_neighbors": 85875137,
      "neighbors": [
        {
          "nbr_mac_id": "9c:BE:Cc:aE:3E:8C",
          "link_metrics": [
            {
              "nbr_intf_macid": "87:7b:5D:bD:Ab:Be",
              "ieee_bridge": true,
              "tx_packet_error": 67051184,
              "tx_packet_ok": 86624513,
              "mac_thrput_capacity": 20426377,
              "link_availability": 0,
              "phy_rate": 53859676,
              "rx_packet_error": 63130145,
              "rx_packet_ok": 19040358,
              "rssi": 35282557
            },
            {
              "nbr_intf_macid": "43:9a:64:6f:aA:aa",
              "ieee_bridge": true,
              "tx_packet_error": 13593344,
              "tx_packet_ok": 11801570,
              "mac_thrput_capacity": 85910385,
              "link_availability": 67,
              "phy_rate": 2176470,
              "rx_packet_error": 54960195,
              "rx_packet_ok": 78897682,
              "rssi": 34003344
            }
          ]
        },
        {
          "nbr_mac_id": "ac:F5:64:aF:eA:Ea",
          "link_metrics": [
            {
              "nbr_intf_macid": "C1:CE:85:4f:75:8C",
              "ieee_bridge": true,
              "tx_packet_error": 61090328,
              "tx_packet_ok": 21947155,
              "mac_thrput_capacity": 59957558,
              "link_availability": 6,
              "phy_rate": 34074792,
              "rx_packet_error": 34199878,
              "rx_packet_ok": 72913887,
              "rssi": 95990520
            }
          ]
        },
        {
          "nbr_mac_id": "13:0d:6b:dE:Ef:BA",
          "link_metrics": [
            {
              "nbr_intf_macid": "08:4F:1c:c9:35:9d",
              "ieee_bridge": false,
              "tx_packet_error": 8676733,
              "tx_packet_ok": 41945894,
              "mac_thrput_capacity": 93087924,
              "link_availability": 41,
              "phy_rate": 56642915,
              "rx_packet_error": 66783426,
              "rx_packet_ok": 50078385,
              "rssi": 84370224
            },
            {
              "nbr_intf_macid": "6D:Fa:a6:be:a1:79",
              "ieee_bridge": false,
              "tx_packet_error": 32744513,
              "tx_packet_ok": 45283698,
              "mac_thrput_capacity": 14490457,
              "link_availability": 23,
              "phy_rate": 32518402,
              "rx_packet_error": 20140868,
              "rx_packet_ok": 38500445,
              "rssi": 19221008
            },
            {
              "nbr_intf_macid": "44:bE:9f:6f:fc:4C",
              "ieee_bridge": false,
              "tx_packet_error": 28786808,
              "tx_packet_ok": 53574651,
              "mac_thrput_capacity": 62953812,
              "link_availability": 49,
              "phy_rate": 23209366,
              "rx_packet_error": 43407016,
              "rx_packet_ok": 83227301,
              "rssi": 73001461
            }
          ]
        },
        {
          "nbr_mac_id": "e7:a7:EB:a2:56:0e",
          "link_metrics": [
            {
              "nbr_intf_macid": "9f:78:b9:1F:aA:16",
              "ieee_bridge": false,
              "tx_packet_error": 27831347,
              "tx_packet_ok": 69759987,
              "mac_thrput_capacity": 33993343,
              "link_availability": 73,
              "phy_rate": 2699981,
              "rx_packet_error": 67692075,
              "rx_packet_ok": 18205065,
              "rssi": 48620621
            },
            {
              "nbr_intf_macid": "C3:E9:Be:aE:E5:CB",
              "ieee_bridge": true,
              "tx_packet_error": 58858275,
              "tx_packet_ok": 44945375,
              "mac_thrput_capacity": 16538719,
              "link_availability": 92,
              "phy_rate": 11801220,
              "rx_packet_error": 18349318,
              "rx_packet_ok": 35366956,
              "rssi": 4286776
            }
          ]
        }
      ],
      "num_non1905_neighbors": 33928039,
      "non1905_neighbors": ["B3:19:1A:b2:CC:6E", "dd:Cc:b9:3c:db:C6", "DE:98:b1:0D:0c:7a", "c2:80:3e:Be:Bc:Fa"],
      "registrar_freq_band": "1B:F7:bb:5A:57:37",
      "non1905_nbr_localintf": "9C:a7:a7:f3:6D:91",
      "1905_nbr_localintf": "32:58:72:3F:a0:FD",
      "local_interface_nbr": 98177152,
      "l2_neighbor_num": 29315467,
      "bridging_tuple_num": 84138762,
      "version": "1905",
      "friendly_name": "incididunt est nostrud",
      "manufacturer_name": "Ut eiusmod",
      "manufacturer_model": "eiusmod nisi aute id",
      "control_url": "http:/1.0.0.1",
      "ipv4_itfr_num": 40437,
      "ipv6_itfr_num": 36932042,
      "interfaces": [
        {
          "interface_id": "Fb:c8:24:59:86:52",
          "media_type": "IEEE 802.11g",
          "network_membership": "BE:4F:76:bb:EE:93",
          "role": "voluptate in cillum qui",
          "ap_channel_band": 96366223,
          "freq_index1": 89577010,
          "freq_index2": 66181794
        },
        {
          "interface_id": "A2:75:8e:ea:b5:88",
          "media_type": "IEEE 802.11b",
          "network_membership": "FF:48:dF:1a:e4:95",
          "role": "culpa",
          "ap_channel_band": 38406494,
          "freq_index1": 5919201,
          "freq_index2": 77051282
        },
        {
          "interface_id": "47:e1:B0:40:3b:96",
          "media_type": "IEEE 802.11af",
          "network_membership": "84:b9:8F:fd:B2:23",
          "role": "sit",
          "ap_channel_band": 17570727,
          "freq_index1": 82136359,
          "freq_index2": 9189596
        },
        {
          "interface_id": "63:Cd:0c:fF:6A:EA",
          "media_type": "IEEE 802.11b",
          "network_membership": "b7:cf:51:Df:eE:1d",
          "role": "minim",
          "ap_channel_band": 49487476,
          "freq_index1": 38232161,
          "freq_index2": 52949003
        }
      ],
      "l2_neighbor": [{ "local_intf_id": "F0:d7:ab:da:0c:2E", "local_nbr_id": "83:1C:36:7b:c8:23" }],
      "bridge_tuple": [
        { "br_mac": ["CF:87:4b:4D:12:8B", "2e:AD:E5:aB:ec:e8"] },
        {
          "br_mac": [
            "0b:54:e7:81:eB:2E",
            "E1:8f:a3:50:c3:23",
            "9b:05:bD:fC:61:5D",
            "b7:F6:7C:35:18:38",
            "0a:Cd:eb:01:8B:ff"
          ]
        }
      ],
      "ipv4_params": [
        {
          "mac_address": "12:03:DA:Fd:a0:Dc",
          "ipv4_addr_type": "dolor esse nisi pariatur Ut",
          "ipv4_address": "5.0.0.2",
          "dhcp_addr": "2.0.2.0"
        },
        {
          "mac_address": "60:A0:CE:39:Ad:0E",
          "ipv4_addr_type": "irure amet quis deserunt",
          "ipv4_address": "1.5.0.5",
          "dhcp_addr": "2.0.0.5"
        },
        {
          "mac_address": "eF:Dc:52:4B:E4:bd",
          "ipv4_addr_type": "amet cupidatat dolor in dolor",
          "ipv4_address": "1.5.0.0",
          "dhcp_addr": "0.2.2.1"
        },
        {
          "mac_address": "bd:E9:b8:Bd:dC:8d",
          "ipv4_addr_type": "volup",
          "ipv4_address": "1.2.5.1",
          "dhcp_addr": "5.1.0.1"
        },
        {
          "mac_address": "eD:f9:90:C0:0e:e2",
          "ipv4_addr_type": "Lorem pariatur reprehenderit",
          "ipv4_address": "5.5.1.5",
          "dhcp_addr": "1.1.5.2"
        }
      ]
    }
  ]
}
```

## nodes

### Give the mac id of self and the neighbor nodes

`nodes`

- type: `Method`

### nodes Type

`object` with following properties:

| Property | Type   | Required     |
| -------- | ------ | ------------ |
| `output` | object | **Required** |

#### output

`output`

- is **required**
- type: `object`

##### output Type

`object` with following properties:

| Property           | Type   | Required |
| ------------------ | ------ | -------- |
| `ieee1905_macaddr` | string | Optional |
| `neighbors`        | array  | Optional |

#### ieee1905_macaddr

mac address in string format

`ieee1905_macaddr`

- is optional
- type: reference

##### ieee1905_macaddr Type

`string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

#### neighbors

`neighbors`

- is optional
- type: reference

##### neighbors Type

Array type: reference

All items must be of the type: `string`

- minimum length: 17 characters
- maximum length: 17 characters All instances must conform to this regular expression (test examples
  [here](<https://regexr.com/?expression=(%5B0-9a-fA-F%5D%7B2%7D%3A)%7B5%7D%5B0-9a-fA-F%5D%7B2%7D>)):

```regex
([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}
```

mac address in string format

### Output Example

```json
{
  "ieee1905_macaddr": "af:AE:D7:de:6C:cF",
  "neighbors": ["da:ec:4c:CB:BE:74", "FB:Fc:13:df:3C:24", "c6:6C:3b:4b:cE:2c", "46:Ec:0F:72:DD:62"]
}
```

## refresh

### Remake the topology tree

`refresh`

- type: `Method`

### refresh Type

`object` with following properties:

| Property | Type | Required |
| -------- | ---- | -------- |
| `output` |      | Optional |

#### output

`output`

- is optional
- type: complex

##### output Type

Unknown type ``.

```json
{
  "definitions": {
    "mac_t": {
      "description": "mac address in string format",
      "type": "string",
      "minLength": 17,
      "maxLength": 17,
      "pattern": "([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}"
    },
    "boolean_t": {
      "type": "string",
      "pattern": "(0|1)"
    },
    "event_type_t": {
      "type": "string",
      "description": "events of node addition or deletion",
      "pattern": "Add|Delete"
    },
    "interface_type_t": {
      "description": "Linux network interface type",
      "type": "string",
      "pattern": "^IEEE 802\\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)"
    },
    "ipv4_t": {
      "description": "IPv4 Address",
      "type": "string",
      "pattern": "([0-255]\\.){3}[0-255]"
    },
    "status_t": {
      "type": "string",
      "pattern": "Incomplete|Available"
    },
    "event_t": {
      "type": "string",
      "pattern": "add|del"
    },
    "timestamp_t": {
      "description": "Time the node was changed",
      "type": "integer",
      "minimum": 0,
      "maximum": 65535
    }
  },
  "out": "{\"definitions\":{\"mac_t\":{\"description\":\"mac address in string format\",\"type\":\"string\",\"minLength\":17,\"maxLength\":17,\"pattern\":\"([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}\"},\"boolean_t\":{\"type\":\"string\",\"pattern\":\"(0|1)\"},\"event_type_t\":{\"type\":\"string\",\"description\":\"events of node addition or deletion\",\"pattern\":\"Add|Delete\"},\"interface_type_t\":{\"description\":\"Linux network interface type\",\"type\":\"string\",\"pattern\":\"^IEEE 802\\\\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)\"},\"ipv4_t\":{\"description\":\"IPv4 Address\",\"type\":\"string\",\"pattern\":\"([0-255]\\\\.){3}[0-255]\"},\"status_t\":{\"type\":\"string\",\"pattern\":\"Incomplete|Available\"},\"event_t\":{\"type\":\"string\",\"pattern\":\"add|del\"},\"timestamp_t\":{\"description\":\"Time the node was changed\",\"type\":\"integer\",\"minimum\":0,\"maximum\":65535}}}",
  "simpletype": "complex"
}
```

### Output Example

```json
{
  "definitions": {
    "mac_t": {
      "description": "mac address in string format",
      "type": "string",
      "minLength": 17,
      "maxLength": 17,
      "pattern": "([0-9a-fA-F]{2}:){5}[0-9a-fA-F]{2}"
    },
    "boolean_t": { "type": "string", "pattern": "(0|1)" },
    "event_type_t": {
      "type": "string",
      "description": "events of node addition or deletion",
      "pattern": "Add|Delete"
    },
    "interface_type_t": {
      "description": "Linux network interface type",
      "type": "string",
      "pattern": "^IEEE 802\\.(3u|3ab|11b|11g|11a|11n 2.4|11n 5.0|11ac|11ad|11af)"
    },
    "ipv4_t": { "description": "IPv4 Address", "type": "string", "pattern": "([0-255]\\.){3}[0-255]" },
    "status_t": { "type": "string", "pattern": "Incomplete|Available" },
    "event_t": { "type": "string", "pattern": "add|del" },
    "timestamp_t": { "description": "Time the node was changed", "type": "integer", "minimum": 0, "maximum": 65535 }
  }
}
```

## status

### Indicates the transient phase of the discovery of the network topology

`status`

- type: `Method`

### status Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `output` | object | Optional |

#### output

`output`

- is optional
- type: `object`

##### output Type

`object` with following properties:

| Property | Type   | Required |
| -------- | ------ | -------- |
| `status` | string | Optional |

#### status

`status`

- is optional
- type: reference

##### status Type

`string`

All instances must conform to this regular expression (test examples
[here](https://regexr.com/?expression=Incomplete%7CAvailable)):

```regex
Incomplete|Available
```

### Output Example

```json
{ "status": "Incomplete" }
```
